@@ -1,16 +1,12 @@
 //! Aggregate Values
 #![allow(dead_code)]
-use crate::column::{ColumnFun, ColumnHeader, ColumnSingle, NamedCol, Writer};
+
+use crate::column::{ColumnFun, ColumnSingle};
 use crate::comp::{Comp, CompMaker};
-use crate::expr::Expr;
-use crate::num::{self, NumFormat};
-use crate::text::Text;
-use crate::util::{err, Error, Result, StringLine, TextLine};
+use crate::prelude::*;
 use lazy_static::lazy_static;
 use std::cell::RefCell;
-use std::cmp::{self, Ordering};
-use std::fmt;
-use std::io::Write;
+use std::cmp;
 use std::rc::Rc;
 use std::sync::Mutex;
 
@@ -194,7 +190,7 @@ impl LineAgg for ExprAgg {
         self.expr.set_var(self.which, self.val);
     }
     fn result(&mut self, w: &mut dyn Write, fmt: NumFormat) -> Result<()> {
-        num::format_hnum(self.value(), fmt, w)
+        fmt.print(self.value(), w)
     }
     fn reset(&mut self) {
         self.val = self.start;
@@ -361,11 +357,11 @@ impl Default for AggType {
 
 /// An Agg with a source column and an output designation
 #[derive(Clone, Debug)]
-pub struct AggCol {
+struct AggCol {
     /// source column
-    pub src: NamedCol,
+    src: NamedCol,
     /// Aggregator
-    pub agg: Agger,
+    agg: Agger,
 }
 
 impl LineAgg for AggCol {
@@ -401,7 +397,7 @@ impl LineAgg for AggCol {
 }
 impl AggCol {
     /// new from AggType and spec
-    pub fn new(spec: &str) -> Result<Self> {
+    fn new(spec: &str) -> Result<Self> {
         if let Some((a, _)) = spec.split_once(',') {
             Self::new2(a, spec)
         } else {
@@ -410,7 +406,7 @@ impl AggCol {
         }
     }
     /// new from AggType and spec
-    pub fn new2(src: &str, spec: &str) -> Result<Self> {
+    fn new2(src: &str, spec: &str) -> Result<Self> {
         Ok(Self {
             src: NamedCol::new_from(src)?,
             agg: Agger::new(spec)?,
@@ -506,16 +502,16 @@ impl Agger {
     }
 }
 
-/// A list of Agger
+/// A collection of buffer-based aggregators
 #[derive(Clone, Default, Debug)]
-pub struct AggerList {
+pub struct AggList {
     /// The aggregators
     v: Vec<Agger>,
     /// fmt
     fmt: NumFormat,
 }
 
-impl AggerList {
+impl AggList {
     /// new
     pub fn new() -> Self {
         Self::default()
@@ -595,7 +591,7 @@ impl AggerList {
     }
 }
 
-/// A list of AggCol
+/// A collection of line-based aggregators
 #[derive(Clone, Default, Debug)]
 pub struct LineAggList {
     /// The aggregators
@@ -793,10 +789,10 @@ impl Merge {
 impl Agg for Merge {
     fn add(&mut self, data: &[u8]) {
         if !data.is_empty() {
-            if !self.data.line.is_empty() {
-                self.data.line.push(self.delim);
+            if !self.data.line().is_empty() {
+                self.data.raw().push(self.delim);
             }
-            self.data.line.extend_from_slice(data);
+            self.data.raw().extend_from_slice(data);
         }
     }
     fn result(&mut self, w: &mut dyn Write, fmt: NumFormat) -> Result<()> {
@@ -814,7 +810,7 @@ impl Agg for Merge {
             });
         }
         if self.do_count {
-            num::format_hnum(self.data.parts.len() as f64, fmt, w)?;
+            fmt.print(self.data.parts().len() as f64, w)?;
         } else {
             let mut num_written = 0;
             for x in &self.data.parts {
@@ -822,7 +818,7 @@ impl Agg for Merge {
                     if num_written > 0 {
                         w.write_all(&[self.out_delim])?;
                     }
-                    w.write_all(x.get(&self.data.line))?;
+                    w.write_all(x.get(self.data.line()))?;
                     num_written += 1;
                     if num_written >= self.max_parts {
                         break;
@@ -833,7 +829,7 @@ impl Agg for Merge {
         Ok(())
     }
     fn reset(&mut self) {
-        self.data.line.clear();
+        self.data.clear();
     }
 }
 
@@ -900,7 +896,7 @@ impl Agg for Mean {
     }
 
     fn result(&mut self, w: &mut dyn Write, fmt: NumFormat) -> Result<()> {
-        num::format_hnum(self.value(), fmt, w)
+        fmt.print(self.value(), w)
     }
     fn value(&self) -> f64 {
         if self.cnt > 0.0 {
@@ -934,7 +930,7 @@ impl Agg for Sum {
         self.val += data.to_f64_lossy();
     }
     fn result(&mut self, w: &mut dyn Write, fmt: NumFormat) -> Result<()> {
-        num::format_hnum(self.value(), fmt, w)
+        fmt.print(self.value(), w)
     }
     fn value(&self) -> f64 {
         self.val
@@ -966,7 +962,7 @@ impl Agg for ASum {
         self.val += self.cnt.counter(data);
     }
     fn result(&mut self, w: &mut dyn Write, fmt: NumFormat) -> Result<()> {
-        num::format_hnum(self.val as f64, fmt, w)
+        fmt.print(self.val as f64, w)
     }
     fn reset(&mut self) {
         self.val = 0;
@@ -995,7 +991,7 @@ impl Agg for AMin {
         self.val = cmp::min(self.val, self.cnt.counter(data));
     }
     fn result(&mut self, w: &mut dyn Write, fmt: NumFormat) -> Result<()> {
-        num::format_hnum(self.val as f64, fmt, w)
+        fmt.print(self.val as f64, w)
     }
     fn reset(&mut self) {
         self.val = usize::MAX;
@@ -1024,7 +1020,7 @@ impl Agg for AMax {
         self.val = cmp::max(self.val, self.cnt.counter(data));
     }
     fn result(&mut self, w: &mut dyn Write, fmt: NumFormat) -> Result<()> {
-        num::format_hnum(self.val as f64, fmt, w)
+        fmt.print(self.val as f64, w)
     }
     fn reset(&mut self) {
         self.val = 0;
@@ -1060,7 +1056,7 @@ impl Agg for AMean {
         self.num += 1;
     }
     fn result(&mut self, w: &mut dyn Write, fmt: NumFormat) -> Result<()> {
-        num::format_hnum(self.val as f64, fmt, w)
+        fmt.print(self.val as f64, w)
     }
     fn reset(&mut self) {
         self.val = 0;
@@ -1232,7 +1228,7 @@ impl Agg for Count {
         self.val += 1;
     }
     fn result(&mut self, w: &mut dyn Write, fmt: NumFormat) -> Result<()> {
-        num::format_hnum(self.value(), fmt, w)
+        fmt.print(self.value(), w)
     }
     fn reset(&mut self) {
         self.val = self.init;
