@@ -1,15 +1,9 @@
 #![allow(dead_code)]
 
-use crate::args::ArgSpec;
-use crate::{arg, arg_enum, arg_pos, args};
+use crate::prelude::*;
 use cdx::binsearch::{equal_range_n, find_end, find_prev, MemMap};
-use cdx::comp::LineCompList;
-use cdx::text::Text;
-use cdx::util::{
-    err, get_writer, write_all_nl, Error, HeaderChecker, HeaderMode, Result, HEADER_MODE,
-};
-use std::io::Write;
-use std::str::FromStr;
+use cdx::prelude::*;
+use cdx::util::{write_all_nl, HeaderChecker, HeaderMode, HEADER_MODE};
 
 #[derive(Debug, Default, PartialEq)]
 struct FileNameColumn {
@@ -102,7 +96,7 @@ pub fn main(argv: &[String]) -> Result<()> {
         arg! {"sub-delim", "s", "Char",  "Delimiter between keys for multi-column searches"},
         arg_pos! {"pattern", "search string",  "Search for this string in each file"},
     ];
-    let (args, files) = args::parse(&prog, &A, argv);
+    let (args, files) = args::parse(&prog, &A, argv)?;
 
     let mut checker = HeaderChecker::new();
     let mut filename: Option<FileNameColumn> = None;
