@@ -1,11 +1,8 @@
 #![allow(dead_code)]
 
-use crate::args::ArgSpec;
-//use crate::{arg, arg_enum, arg_pos, args};
-use crate::args;
+use crate::prelude::*;
 use cdx::expr::calc;
-use cdx::num;
-use cdx::util::{prerr, Reader, Result};
+use cdx::prelude::*;
 
 pub fn main(argv: &[String]) -> Result<()> {
     let prog = args::ProgSpec::new("Evaluate Expressions.", args::FileCount::Many);
@@ -13,7 +10,7 @@ pub fn main(argv: &[String]) -> Result<()> {
 //        arg_enum! {"header", "h", "Mode", "header requirements", &HEADER_MODE},
 //        arg! {"key", "k", "Spec", "How to compare value to lines"},
     ];
-    let (args, files) = args::parse(&prog, &A, argv);
+    let (args, files) = args::parse(&prog, &A, argv)?;
 
     for x in args {
         if x.name == "header" {
@@ -33,16 +30,16 @@ pub fn main(argv: &[String]) -> Result<()> {
                 Ok(v) => {
                     let mut vec: Vec<u8> = Vec::new();
                     vec.clear();
-                    num::format_hnum(v, num::NumFormat::Plain(4), &mut vec)?;
+                    NumFormat::Plain(4).print(v, &mut vec)?;
                     prerr(&[&vec]);
                     vec.clear();
-                    num::format_hnum(v, num::NumFormat::Float(4), &mut vec)?;
+                    NumFormat::Float(4).print(v, &mut vec)?;
                     prerr(&[&vec]);
                     vec.clear();
-                    num::format_hnum(v, num::NumFormat::Power2, &mut vec)?;
+                    NumFormat::Power2.print(v, &mut vec)?;
                     prerr(&[&vec]);
                     vec.clear();
-                    num::format_hnum(v, num::NumFormat::Power10, &mut vec)?;
+                    NumFormat::Power10.print(v, &mut vec)?;
                     prerr(&[&vec]);
                     //		    println!("{}", num::format_hnum(v as i64, num::NumFormat::Power2, ),
                 }
