@@ -1,13 +1,7 @@
-use crate::args::ArgSpec;
-use crate::{arg, arg_enum, args};
-use cdx::column::{ColumnCount, ColumnHeader, ColumnLiteral, ColumnWhole, Writer};
-use cdx::matcher::{Combiner, Match, MatchMaker, MatcherList};
-use cdx::text::Text;
-use cdx::util::{
-    err, get_reader, get_writer, Error, HeaderChecker, HeaderMode, Reader, Result, HEADER_MODE,
-};
-use std::io::{BufRead, Read, Write};
-use std::str::FromStr;
+use crate::prelude::*;
+use cdx::column::{ColumnCount, ColumnLiteral, ColumnWhole};
+use cdx::prelude::*;
+use cdx::util::{get_reader, HeaderChecker, HeaderMode, HEADER_MODE};
 
 #[derive(Debug, Copy, Clone, PartialEq)]
 enum PadMode {
@@ -94,13 +88,13 @@ pub fn main(argv: &[String]) -> Result<()> {
         arg! {"begin", "b", "",  "Shortcut for --number number,1,begin"},
         arg! {"end", "e", "",  "Shortcut for --number number,1,end"},
     ];
-    let (args, files) = args::parse(&prog, &A, argv);
+    let (args, files) = args::parse(&prog, &A, argv)?;
 
     let mut checker = HeaderChecker::new();
     let mut pad = PadMode::All;
     let mut num = LineNumber::new();
-    let mut skips = MatcherList::new(Combiner::Or);
-    let mut removes = MatcherList::new(Combiner::Or);
+    let mut skips = MatcherList::new();
+    let mut removes = MatcherList::new();
 
     for x in args {
         if x.name == "header" {
@@ -122,9 +116,9 @@ pub fn main(argv: &[String]) -> Result<()> {
         } else if x.name == "end" {
             num.set("number,1,end")?;
         } else if x.name == "skip" {
-            skips.push(MatchMaker::make(&x.value)?);
+            skips.push(&x.value)?;
         } else if x.name == "remove" {
-            removes.push(MatchMaker::make(&x.value)?);
+            removes.push(&x.value)?;
         } else {
             unreachable!();
         }
