@@ -1,7 +1,7 @@
 use cdx::util::{Error, Result};
 use std::env;
 
-mod args;
+pub mod args;
 mod binsearch_main;
 mod calc_main;
 mod cat_main;
@@ -9,8 +9,10 @@ mod cdxmain;
 mod cgrep_main;
 mod cut_main;
 mod filegen_main;
+pub mod globals;
 mod join_main;
 mod paste_main;
+pub mod prelude;
 mod sample_main;
 mod sort_main;
 mod tabs_main;
