@@ -1,8 +1,5 @@
-use crate::args::ArgSpec;
-use crate::{arg, arg_enum, args};
-use cdx::column::{ColumnHeader, DupColHandling, ScopedValues};
-use cdx::util::{err, get_writer, Error, Reader, Result};
-use std::io::Write;
+use crate::prelude::*;
+use cdx::prelude::*;
 
 /*
 What if different delims
@@ -38,7 +35,7 @@ pub fn main(argv: &[String]) -> Result<()> {
         arg! {"rename-sloppy", "R", "", "Not an error is some renames not used."},
         arg_enum! {"dups", "D", "Mode", "Duplicate Column Handling", &["Fail", "Allow", "Numeric"]},
     ];
-    let (args, files) = args::parse(&prog, &A, argv);
+    let (args, files) = args::parse(&prog, &A, argv)?;
 
     let mut end_mode = EndMode::Exact;
     let mut dflt = ScopedValues::new();
