@@ -1,12 +1,6 @@
-use crate::arg;
-use crate::args;
-use crate::args::ArgSpec;
-use cdx::agg::{AggMaker, LineAggList};
-use cdx::column::{ColumnHeader, Writer};
-use cdx::comp::{CompMaker, LineComp, LineCompList};
-use cdx::util::{err, get_writer, Error, Reader, Result, TextLine};
-use std::cmp::Ordering;
-use std::io::Write;
+use crate::prelude::*;
+use cdx::comp::{CompMaker, LineComp};
+use cdx::prelude::*;
 
 // --min
 // --max
@@ -169,7 +163,7 @@ pub fn main(argv: &[String]) -> Result<()> {
         arg! {"which", "w", "(First,Last,Min,Max)[,LineCompare]", "Which of the matching lines should be printed."},
         arg! {"agg-help", "", "", "Print help for aggregators"},
     ];
-    let (args, files) = args::parse(&prog, &A, argv);
+    let (args, files) = args::parse(&prog, &A, argv)?;
 
     let mut agg = LineAggList::new();
     let mut comp = LineCompList::new();
@@ -188,9 +182,6 @@ pub fn main(argv: &[String]) -> Result<()> {
             agg.push_append(&x.value)?;
         } else if x.name == "agg-pre" {
             agg.push_prefix(&x.value)?;
-        } else if x.name == "agg-help" {
-            AggMaker::help();
-            return Ok(());
         } else {
             unreachable!();
         }
@@ -261,13 +252,13 @@ pub fn main(argv: &[String]) -> Result<()> {
     } else if count.which == Which::Last {
         loop {
             if f.getline()? {
-                count.write(&mut w, matches, &f.prev_line(1).line, f.delim())?;
+                count.write(&mut w, matches, f.prev_line(1).line(), f.delim())?;
                 break;
             }
             if comp.equal_cols(f.prev_line(1), f.curr_line()) {
                 matches += 1;
             } else {
-                count.write(&mut w, matches, &f.prev_line(1).line, f.delim())?;
+                count.write(&mut w, matches, f.prev_line(1).line(), f.delim())?;
                 matches = 1;
             }
         }
@@ -285,14 +276,14 @@ pub fn main(argv: &[String]) -> Result<()> {
         let mut tmp = f.curr_line().clone();
         loop {
             if f.getline()? {
-                count.write(&mut w, matches, &tmp.line, f.delim())?;
+                count.write(&mut w, matches, tmp.line(), f.delim())?;
                 break;
             }
             if comp.equal_cols(f.prev_line(1), f.curr_line()) {
                 count.assign(&mut tmp, f.curr_line());
                 matches += 1;
             } else {
-                count.write(&mut w, matches, &tmp.line, f.delim())?;
+                count.write(&mut w, matches, tmp.line(), f.delim())?;
                 tmp.assign(f.curr_line());
                 matches = 1;
             }
