@@ -1,7 +1,6 @@
 //! Format plain text to a fixed width terminal
 
-use crate::util::{get_writer, Reader, Result, StringLine};
-use std::io::Write;
+use crate::prelude::*;
 use unicode_truncate::UnicodeTruncateStr;
 use unicode_width::UnicodeWidthStr;
 
@@ -74,7 +73,7 @@ pub fn show(file: &str, screen: &Rect) -> Result<()> {
     if !f.is_done() {
         while lines.len() < screen.height {
             let mut s = StringLine::new();
-            s.line = String::from_utf8_lossy(&f.curr().line).to_string();
+            s.line = String::from_utf8_lossy(f.curr().line()).to_string();
             s.split(f.delim());
             lines.push(s);
             if f.getline()? {
@@ -146,7 +145,7 @@ pub fn show2(file: &str, screen: &Rect, w: &mut Vec<String>) -> Result<usize> {
     if !f.is_done() {
         while lines.len() < screen.height {
             let mut s = StringLine::new();
-            s.line = String::from_utf8_lossy(&f.curr().line).to_string();
+            s.line = String::from_utf8_lossy(f.curr().line()).to_string();
             s.split(f.delim());
             lines.push(s);
             if f.getline()? {
