@@ -1,20 +1,19 @@
 //! Misc utility stuff
 
 use crate::column::ColumnHeader;
-use crate::comp::{CompMaker, Compare, LineCompList};
-use crate::text::Text;
+use crate::comp::{CompMaker, Compare};
+use crate::prelude::*;
 use flate2::read::MultiGzDecoder;
 use fs_err as fs;
 use lazy_static::lazy_static;
 use regex::Regex;
-use std::cmp::{self, Ordering};
+use std::cmp;
 use std::error;
 use std::ffi::OsStr;
-use std::io::{self, BufRead, Read, Write};
+use std::io;
 use std::ops::{Deref, DerefMut};
 use std::path::Path;
-use std::str::FromStr;
-use std::{fmt, str};
+use std::str;
 use tokio_stream::StreamExt;
 
 /// Shorthand for returning an error Result
@@ -36,7 +35,7 @@ macro_rules! err_type {
     };
 }
 
-/// Various errors
+/// Common CDX error type
 #[derive(Debug)]
 #[non_exhaustive]
 #[allow(clippy::large_enum_variant)]
@@ -65,8 +64,11 @@ pub enum Error {
     NeedLookup,
     /// be an error, but don't report anything
     Silent,
+    /// Exit with status code zero
+    NoError,
 }
-/// Result type for cdx
+
+/// Common CDX result type
 pub type Result<T> = core::result::Result<T, Error>;
 impl error::Error for Error {}
 
@@ -75,6 +77,7 @@ impl Error {
     pub fn suppress(&self) -> bool {
         match self {
             Error::IoError(err) => err.kind() == io::ErrorKind::BrokenPipe,
+            Error::NoError => true,
             _ => false,
         }
     }
@@ -115,6 +118,7 @@ impl fmt::Display for Error {
                 "ColumnSet.lookup() must be called before ColumnSet.select()"
             )?,
             Error::Silent => write!(f, "Silent")?,
+            Error::NoError => write!(f, "Not an error.")?,
         }
         Ok(())
     }
@@ -151,6 +155,22 @@ impl Tri {
             err!("Tri value must be yes, no or maybe '{}'", x)
         }
     }
+    /// return Yes is x is true, else Maybe
+    pub const fn yes_if(x: bool) -> Self {
+        if x {
+            Self::Yes
+        } else {
+            Self::Maybe
+        }
+    }
+    /// return No is x is true, else Maybe
+    pub const fn no_if(x: bool) -> Self {
+        if x {
+            Self::No
+        } else {
+            Self::Maybe
+        }
+    }
 }
 
 /// pointers into a vector, simulating a slice without the ownership issues
@@ -205,10 +225,9 @@ impl FakeSlice {
     }
 }
 
-/// A line of a text file, broken into fields.
-/// Access to the `lines` and `parts` is allowed, but should seldom be necessary
-/// `line` includes the trailing newline, but no field contains the newline
-/// An empty line contains one empty field
+/// A line of a text file, broken into columns.
+/// A line ends with a newline character, but column values do not.
+/// An empty line contains one empty column
 ///```
 /// use std::io::BufRead;
 /// let mut data = b"one\ttwo\tthree\n";
@@ -222,14 +241,15 @@ impl FakeSlice {
 /// assert_eq!(line.get(1), b"two");
 ///```
 #[derive(Debug, Clone, Default)]
+// pub(crate) because the borrow checker can be a nuisance.
 pub struct TextLine {
-    /// The whole input line, with newline
-    pub line: Vec<u8>,
-    /// the individual columns
-    pub parts: Vec<FakeSlice>,
+    // The whole input line, with newline
+    pub(crate) line: Vec<u8>,
+    // the individual columns, without newline
+    pub(crate) parts: Vec<FakeSlice>,
 }
 
-/// as TextLine, but String rather than Vec<u8>
+/// as TextLine, but [String] rather than `Vec<u8>`
 #[derive(Debug, Clone, Default)]
 pub struct StringLine {
     /// The whole input line, with newline
@@ -282,6 +302,22 @@ pub fn write_all_nl(w: &mut impl Write, buf: &[u8]) -> Result<()> {
 }
 
 impl TextLine {
+    /// whole line, with newline
+    pub fn parts(&mut self) -> &mut Vec<FakeSlice> {
+        &mut self.parts
+    }
+    /// whole line, with newline
+    pub fn line(&self) -> &[u8] {
+        &self.line
+    }
+    /// whole line, without newline
+    pub fn line_nl(&self) -> &[u8] {
+        &self.line[..self.line.len() - 1]
+    }
+    /// whole line, with newline, as Vec
+    pub fn raw(&mut self) -> &mut Vec<u8> {
+        &mut self.line
+    }
     /// assign TextLine into existing TextLine, avoiding allocation if possible
     pub fn assign(&mut self, x: &Self) {
         self.line.clear();
@@ -303,7 +339,8 @@ impl TextLine {
             index: 0,
         }
     }
-    fn clear(&mut self) {
+    /// empty the line
+    pub fn clear(&mut self) {
         self.parts.clear();
         self.line.clear();
     }
@@ -948,8 +985,7 @@ impl FileLocList {
 }
 
 #[derive(Debug, Default)]
-/// File reader for text file broken into lines with columns
-/// previous N lines are still available
+/// Text file reader. Lines broken into columns, with lookback
 pub struct Reader {
     file: Infile,
     lines: Vec<TextLine>,
